@@ -1,4 +1,4 @@
-#  Copyright 2017-2020 Reveal Energy Services, Inc 
+#  Copyright 2017-2021 Reveal Energy Services, Inc 
 #
 #  Licensed under the Apache License, Version 2.0 (the "License"); 
 #  you may not use this file except in compliance with the License. 
@@ -15,8 +15,16 @@
 # This file is part of Orchid and related technologies.
 #
 
+import uuid
+
+import deal
 import toolz.curried as toolz
 
+import orchid.validation
+
+# noinspection PyUnresolvedReferences
+from System import Guid
+
 
 # These methods in this module are based on the StackOverflow post:
 # https://stackoverflow.com/questions/36580931/python-property-factory-or-descriptor-class-for-wrapping-an-external-library
@@ -107,7 +115,12 @@ def transformed_dom_property_iterator(attribute_name, docstring, transformer):
     return property(fget=getter, doc=docstring, fset=None)
 
 
+def as_uuid(guid: Guid):
+    return uuid.UUID(str(guid))
+
+
 class DotNetAdapter:
+    @deal.pre(orchid.validation.arg_not_none)
     def __init__(self, adaptee):
         """
         Construct an instance adapting a .NET IStage.
@@ -115,7 +128,7 @@ class DotNetAdapter:
         """
         self._adaptee = adaptee
 
-    object_id = dom_property('object_id', 'The object ID of the adapted .NET DOM object.')
+    object_id = transformed_dom_property('object_id', 'The object ID of the adapted .NET DOM object.', as_uuid)
 
     def dom_object(self):
         """
