@@ -1,4 +1,4 @@
-#  Copyright 2017-2020 Reveal Energy Services, Inc 
+#  Copyright 2017-2021 Reveal Energy Services, Inc 
 #
 #  Licensed under the Apache License, Version 2.0 (the "License"); 
 #  you may not use this file except in compliance with the License. 
@@ -20,26 +20,20 @@ from typing import List, Tuple, Iterable
 import deal
 import toolz.curried as toolz
 
-import orchid.dot_net_dom_access as dna
-from orchid.native_well_adapter import NativeWellAdapter
-from orchid.native_monitor_curve_facade import NativeMonitorCurveFacade
+from orchid import (
+    dot_net_dom_access as dna,
+    native_well_adapter as nwa,
+    native_monitor_curve_adapter as mca,
+    unit_system as units,
+)
 from orchid.project_loader import ProjectLoader
-import orchid.project_units as project_units
-import orchid.unit_system as units
 
 # noinspection PyUnresolvedReferences
 from Orchid.FractureDiagnostics import IWell, UnitSystem
 # noinspection PyUnresolvedReferences
 import UnitsNet
 
-
-def as_unit_system(net_unit_system: UnitSystem):
-    if net_unit_system == UnitSystem.USOilfield():
-        return units.UsOilfield
-    elif net_unit_system == UnitSystem.Metric():
-        return units.Metric
-    else:
-        raise ValueError(f'Unrecognized unit system: {net_unit_system}')
+from orchid.unit_system import as_unit_system
 
 
 class Project(dna.DotNetAdapter):
@@ -60,7 +54,7 @@ class Project(dna.DotNetAdapter):
     name = dna.dom_property('name', 'The name of this project.')
     project_units = dna.transformed_dom_property('project_units', 'The project unit system.', as_unit_system)
     wells = dna.transformed_dom_property_iterator('wells', 'An iterator of all the wells in this project.',
-                                                  NativeWellAdapter)
+                                                  nwa.NativeWellAdapter)
 
     def default_well_colors(self) -> List[Tuple[float, float, float]]:
         """
@@ -70,7 +64,7 @@ class Project(dna.DotNetAdapter):
         result = list(map(tuple, self._project_loader.native_project().PlottingSettings.GetDefaultWellColors()))
         return result
 
-    def monitor_curves(self) -> Iterable[NativeMonitorCurveFacade]:
+    def monitor_curves(self) -> Iterable[mca.NativeMonitorCurveAdapter]:
         """
             Return a sequence of well time series for this project.
         Returns:
@@ -78,18 +72,26 @@ class Project(dna.DotNetAdapter):
         """
         native_time_series_list_items = self._project_loader.native_project().WellTimeSeriesList.Items
         if len(native_time_series_list_items) > 0:
-            return toolz.map(NativeMonitorCurveFacade,
+            return toolz.map(mca.NativeMonitorCurveAdapter,
                              self._project_loader.native_project().WellTimeSeriesList.Items)
         else:
             return []
 
-    def unit_abbreviation(self, physical_quantity):
-        """
-        Return the abbreviation for the specified `physical_quantity` of this project.
-        :param physical_quantity: The name of the physical quantity.
-        :return: The abbreviation of the specified physical quantity.
-        """
-        return project_units.unit_abbreviation(self._project_loader.native_project(), physical_quantity)
+    def proppant_concentration_mass_unit(self):
+        if self.project_units == units.UsOilfield:
+            return units.UsOilfield.MASS
+        elif self.project_units == units.Metric:
+            return units.Metric.MASS
+        else:
+            raise ValueError(f'Unknown unit system: {self.project_units}')
+
+    def slurry_rate_volume_unit(self):
+        if self.project_units == units.UsOilfield:
+            return units.UsOilfield.VOLUME
+        elif self.project_units == units.Metric:
+            return units.Metric.VOLUME
+        else:
+            raise ValueError(f'Unknown unit system: {self.project_units}')
 
     def wells_by_name(self, name) -> Iterable[IWell]:
         """
